# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radioconfig.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='radioconfig.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\023com.geeksville.meshB\021RadioConfigProtosH\003Z!github.com/meshtastic/gomeshproto',
  serialized_pb=b'\n\x11radioconfig.proto\"\xd8\x1b\n\x0bRadioConfig\x12\x31\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1c.RadioConfig.UserPreferences\x1a\x95\x1b\n\x0fUserPreferences\x12\x1f\n\x17position_broadcast_secs\x18\x01 \x01(\r\x12)\n!position_broadcast_smart_disabled\x18\x11 \x01(\x08\x12\x1b\n\x13send_owner_interval\x18\x02 \x01(\r\x12\x1b\n\x13wait_bluetooth_secs\x18\x04 \x01(\r\x12\x16\n\x0escreen_on_secs\x18\x05 \x01(\r\x12\x1a\n\x12phone_timeout_secs\x18\x06 \x01(\r\x12\x1d\n\x15phone_sds_timeout_sec\x18\x07 \x01(\r\x12\x1d\n\x15mesh_sds_timeout_secs\x18\x08 \x01(\r\x12\x10\n\x08sds_secs\x18\t \x01(\r\x12\x0f\n\x07ls_secs\x18\n \x01(\r\x12\x15\n\rmin_wake_secs\x18\x0b \x01(\r\x12\x11\n\twifi_ssid\x18\x0c \x01(\t\x12\x15\n\rwifi_password\x18\r \x01(\t\x12\x14\n\x0cwifi_ap_mode\x18\x0e \x01(\x08\x12\x1b\n\x06region\x18\x0f \x01(\x0e\x32\x0b.RegionCode\x12&\n\x0e\x63harge_current\x18\x10 \x01(\x0e\x32\x0e.ChargeCurrent\x12\x13\n\x04role\x18\x12 \x01(\x0e\x32\x05.Role\x12\x14\n\x0cis_low_power\x18& \x01(\x08\x12\x16\n\x0e\x66ixed_position\x18\' \x01(\x08\x12\x17\n\x0fserial_disabled\x18( \x01(\x08\x12\x1f\n\x17location_share_disabled\x18  \x01(\x08\x12\x14\n\x0cgps_disabled\x18! \x01(\x08\x12\x1b\n\x13gps_update_interval\x18\" \x01(\r\x12\x18\n\x10gps_attempt_time\x18$ \x01(\r\x12\x15\n\rgps_accept_2d\x18- \x01(\x08\x12\x13\n\x0bgps_max_dop\x18. \x01(\r\x12\x18\n\x10\x66requency_offset\x18) \x01(\x02\x12\x13\n\x0bmqtt_server\x18* \x01(\t\x12\x15\n\rmqtt_disabled\x18+ \x01(\x08\x12(\n\ngps_format\x18, \x01(\x0e\x32\x14.GpsCoordinateFormat\x12\x15\n\rfactory_reset\x18\x64 \x01(\x08\x12\x19\n\x11\x64\x65\x62ug_log_enabled\x18\x65 \x01(\x08\x12\x17\n\x0fignore_incoming\x18g \x03(\r\x12\x1d\n\x15serial_module_enabled\x18x \x01(\x08\x12\x1a\n\x12serial_module_echo\x18y \x01(\x08\x12\x19\n\x11serial_module_rxd\x18z \x01(\r\x12\x19\n\x11serial_module_txd\x18{ \x01(\r\x12\x45\n\x12serial_module_baud\x18\xb0\x01 \x01(\x0e\x32(.RadioConfig.UserPreferences.Serial_Baud\x12\x1d\n\x15serial_module_timeout\x18| \x01(\r\x12\x44\n\x12serial_module_mode\x18} \x01(\x0e\x32(.RadioConfig.UserPreferences.Serial_Mode\x12\'\n\x1f\x65xt_notification_module_enabled\x18~ \x01(\x08\x12)\n!ext_notification_module_output_ms\x18\x7f \x01(\r\x12\'\n\x1e\x65xt_notification_module_output\x18\x80\x01 \x01(\r\x12\'\n\x1e\x65xt_notification_module_active\x18\x81\x01 \x01(\x08\x12.\n%ext_notification_module_alert_message\x18\x82\x01 \x01(\x08\x12+\n\"ext_notification_module_alert_bell\x18\x83\x01 \x01(\x08\x12\"\n\x19range_test_module_enabled\x18\x84\x01 \x01(\x08\x12!\n\x18range_test_module_sender\x18\x85\x01 \x01(\r\x12\x1f\n\x16range_test_module_save\x18\x86\x01 \x01(\x08\x12%\n\x1cstore_forward_module_enabled\x18\x94\x01 \x01(\x08\x12\'\n\x1estore_forward_module_heartbeat\x18\x95\x01 \x01(\x08\x12%\n\x1cstore_forward_module_records\x18\x89\x01 \x01(\r\x12\x30\n\'store_forward_module_history_return_max\x18\x8a\x01 \x01(\r\x12\x33\n*store_forward_module_history_return_window\x18\x8b\x01 \x01(\r\x12\x39\n0telemetry_module_environment_measurement_enabled\x18\x8c\x01 \x01(\x08\x12\x34\n+telemetry_module_environment_screen_enabled\x18\x8d\x01 \x01(\x08\x12@\n7telemetry_module_environment_read_error_count_threshold\x18\x8e\x01 \x01(\r\x12\x30\n\'telemetry_module_device_update_interval\x18\x8f\x01 \x01(\r\x12\x37\n.telemetry_module_environment_recovery_interval\x18\x90\x01 \x01(\r\x12\x38\n/telemetry_module_environment_display_fahrenheit\x18\x91\x01 \x01(\x08\x12\x63\n(telemetry_module_environment_sensor_type\x18\x92\x01 \x01(\x0e\x32\x30.RadioConfig.UserPreferences.TelemetrySensorType\x12\x30\n\'telemetry_module_environment_sensor_pin\x18\x93\x01 \x01(\r\x12\x17\n\x0eposition_flags\x18\x96\x01 \x01(\r\x12\x1a\n\x11is_always_powered\x18\x97\x01 \x01(\x08\x12\"\n\x19\x61uto_screen_carousel_secs\x18\x98\x01 \x01(\r\x12\'\n\x1eon_battery_shutdown_after_secs\x18\x99\x01 \x01(\r\x12\x12\n\thop_limit\x18\x9a\x01 \x01(\r\x12\x16\n\rmqtt_username\x18\x9b\x01 \x01(\t\x12\x16\n\rmqtt_password\x18\x9c\x01 \x01(\t\x12\x1c\n\x13is_lora_tx_disabled\x18\x9d\x01 \x01(\x08\x12\x18\n\x0fis_power_saving\x18\x9e\x01 \x01(\x08\x12\x18\n\x0frotary1_enabled\x18\xa0\x01 \x01(\x08\x12\x1a\n\x11inputbroker_pin_a\x18\xa1\x01 \x01(\r\x12\x1a\n\x11inputbroker_pin_b\x18\xa2\x01 \x01(\r\x12\x1e\n\x15inputbroker_pin_press\x18\xa3\x01 \x01(\r\x12.\n\x14inputbroker_event_cw\x18\xa4\x01 \x01(\x0e\x32\x0f.InputEventChar\x12/\n\x15inputbroker_event_ccw\x18\xa5\x01 \x01(\x0e\x32\x0f.InputEventChar\x12\x31\n\x17inputbroker_event_press\x18\xa6\x01 \x01(\x0e\x32\x0f.InputEventChar\x12\x18\n\x0fupdown1_enabled\x18\xa7\x01 \x01(\x08\x12&\n\x1d\x63\x61nned_message_module_enabled\x18\xaa\x01 \x01(\x08\x12\x31\n(canned_message_module_allow_input_source\x18\xab\x01 \x01(\t\x12(\n\x1f\x63\x61nned_message_module_send_bell\x18\xad\x01 \x01(\x08\x12 \n\x17mqtt_encryption_enabled\x18\xae\x01 \x01(\x08\x12 \n\x17\x61\x64\x63_multiplier_override\x18\xaf\x01 \x01(\x02\x12\x35\n,telemetry_module_environment_update_interval\x18\xb1\x01 \x01(\r\"\xd1\x01\n\x0bSerial_Baud\x12\x10\n\x0c\x42\x41UD_Default\x10\x00\x12\r\n\tBAUD_2400\x10\x01\x12\r\n\tBAUD_4800\x10\x02\x12\r\n\tBAUD_9600\x10\x03\x12\x0e\n\nBAUD_19200\x10\x04\x12\x0e\n\nBAUD_38400\x10\x05\x12\x0e\n\nBAUD_57600\x10\x06\x12\x0f\n\x0b\x42\x41UD_115200\x10\x07\x12\x0f\n\x0b\x42\x41UD_230400\x10\x08\x12\x0f\n\x0b\x42\x41UD_460800\x10\t\x12\x0f\n\x0b\x42\x41UD_576000\x10\n\x12\x0f\n\x0b\x42\x41UD_921600\x10\x0b\"@\n\x0bSerial_Mode\x12\x10\n\x0cMODE_Default\x10\x00\x12\x0f\n\x0bMODE_SIMPLE\x10\x01\x12\x0e\n\nMODE_PROTO\x10\x02\"\x88\x01\n\x13TelemetrySensorType\x12\x08\n\x04None\x10\x00\x12\t\n\x05\x44HT11\x10\x01\x12\x0b\n\x07\x44S18B20\x10\x02\x12\t\n\x05\x44HT12\x10\x03\x12\t\n\x05\x44HT21\x10\x04\x12\t\n\x05\x44HT22\x10\x05\x12\n\n\x06\x42ME280\x10\x06\x12\n\n\x06\x42ME680\x10\x07\x12\x0b\n\x07MCP9808\x10\x08\x12\t\n\x05SHTC3\x10\tJ\x06\x08\x88\x01\x10\x89\x01*\x81\x01\n\nRegionCode\x12\t\n\x05Unset\x10\x00\x12\x06\n\x02US\x10\x01\x12\t\n\x05\x45U433\x10\x02\x12\t\n\x05\x45U868\x10\x03\x12\x06\n\x02\x43N\x10\x04\x12\x06\n\x02JP\x10\x05\x12\x07\n\x03\x41NZ\x10\x06\x12\x06\n\x02KR\x10\x07\x12\x06\n\x02TW\x10\x08\x12\x06\n\x02RU\x10\t\x12\x06\n\x02IN\x10\n\x12\t\n\x05NZ865\x10\x0b\x12\x06\n\x02TH\x10\x0c*@\n\x04Role\x12\n\n\x06\x43lient\x10\x00\x12\x0e\n\nClientMute\x10\x01\x12\n\n\x06Router\x10\x02\x12\x10\n\x0cRouterClient\x10\x03*\xd1\x01\n\rChargeCurrent\x12\x0b\n\x07MAUnset\x10\x00\x12\t\n\x05MA100\x10\x01\x12\t\n\x05MA190\x10\x02\x12\t\n\x05MA280\x10\x03\x12\t\n\x05MA360\x10\x04\x12\t\n\x05MA450\x10\x05\x12\t\n\x05MA550\x10\x06\x12\t\n\x05MA630\x10\x07\x12\t\n\x05MA700\x10\x08\x12\t\n\x05MA780\x10\t\x12\t\n\x05MA880\x10\n\x12\t\n\x05MA960\x10\x0b\x12\n\n\x06MA1000\x10\x0c\x12\n\n\x06MA1080\x10\r\x12\n\n\x06MA1160\x10\x0e\x12\n\n\x06MA1240\x10\x0f\x12\n\n\x06MA1320\x10\x10*\x83\x01\n\x13GpsCoordinateFormat\x12\x10\n\x0cGpsFormatDec\x10\x00\x12\x10\n\x0cGpsFormatDMS\x10\x01\x12\x10\n\x0cGpsFormatUTM\x10\x02\x12\x11\n\rGpsFormatMGRS\x10\x03\x12\x10\n\x0cGpsFormatOLC\x10\x04\x12\x11\n\rGpsFormatOSGR\x10\x05*\xbc\x01\n\rPositionFlags\x12\x11\n\rPOS_UNDEFINED\x10\x00\x12\x10\n\x0cPOS_ALTITUDE\x10\x01\x12\x0f\n\x0bPOS_ALT_MSL\x10\x02\x12\x0f\n\x0bPOS_GEO_SEP\x10\x04\x12\x0b\n\x07POS_DOP\x10\x08\x12\r\n\tPOS_HVDOP\x10\x10\x12\x0f\n\x0bPOS_BATTERY\x10 \x12\x11\n\rPOS_SATINVIEW\x10@\x12\x10\n\x0bPOS_SEQ_NOS\x10\x80\x01\x12\x12\n\rPOS_TIMESTAMP\x10\x80\x02*\x83\x01\n\x0eInputEventChar\x12\x0c\n\x08KEY_NONE\x10\x00\x12\n\n\x06KEY_UP\x10\x11\x12\x0c\n\x08KEY_DOWN\x10\x12\x12\x0c\n\x08KEY_LEFT\x10\x13\x12\r\n\tKEY_RIGHT\x10\x14\x12\x0e\n\nKEY_SELECT\x10\n\x12\x0c\n\x08KEY_BACK\x10\x1b\x12\x0e\n\nKEY_CANCEL\x10\x18\x42M\n\x13\x63om.geeksville.meshB\x11RadioConfigProtosH\x03Z!github.com/meshtastic/gomeshprotob\x06proto3'
)

_REGIONCODE = _descriptor.EnumDescriptor(
  name='RegionCode',
  full_name='RegionCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unset', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='US', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EU433', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EU868', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JP', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANZ', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TW', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RU', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NZ865', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TH', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3569,
  serialized_end=3698,
)
_sym_db.RegisterEnumDescriptor(_REGIONCODE)

RegionCode = enum_type_wrapper.EnumTypeWrapper(_REGIONCODE)
_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Client', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ClientMute', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Router', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RouterClient', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3700,
  serialized_end=3764,
)
_sym_db.RegisterEnumDescriptor(_ROLE)

Role = enum_type_wrapper.EnumTypeWrapper(_ROLE)
_CHARGECURRENT = _descriptor.EnumDescriptor(
  name='ChargeCurrent',
  full_name='ChargeCurrent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAUnset', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA100', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA190', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA280', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA360', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA450', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA550', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA630', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA700', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA780', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA880', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA960', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA1000', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA1080', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA1160', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA1240', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MA1320', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3767,
  serialized_end=3976,
)
_sym_db.RegisterEnumDescriptor(_CHARGECURRENT)

ChargeCurrent = enum_type_wrapper.EnumTypeWrapper(_CHARGECURRENT)
_GPSCOORDINATEFORMAT = _descriptor.EnumDescriptor(
  name='GpsCoordinateFormat',
  full_name='GpsCoordinateFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GpsFormatDec', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GpsFormatDMS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GpsFormatUTM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GpsFormatMGRS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GpsFormatOLC', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GpsFormatOSGR', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3979,
  serialized_end=4110,
)
_sym_db.RegisterEnumDescriptor(_GPSCOORDINATEFORMAT)

GpsCoordinateFormat = enum_type_wrapper.EnumTypeWrapper(_GPSCOORDINATEFORMAT)
_POSITIONFLAGS = _descriptor.EnumDescriptor(
  name='PositionFlags',
  full_name='PositionFlags',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POS_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_ALTITUDE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_ALT_MSL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_GEO_SEP', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_DOP', index=4, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_HVDOP', index=5, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_BATTERY', index=6, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_SATINVIEW', index=7, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_SEQ_NOS', index=8, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POS_TIMESTAMP', index=9, number=256,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4113,
  serialized_end=4301,
)
_sym_db.RegisterEnumDescriptor(_POSITIONFLAGS)

PositionFlags = enum_type_wrapper.EnumTypeWrapper(_POSITIONFLAGS)
_INPUTEVENTCHAR = _descriptor.EnumDescriptor(
  name='InputEventChar',
  full_name='InputEventChar',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_UP', index=1, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_DOWN', index=2, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_LEFT', index=3, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_RIGHT', index=4, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_SELECT', index=5, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_BACK', index=6, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_CANCEL', index=7, number=24,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4304,
  serialized_end=4435,
)
_sym_db.RegisterEnumDescriptor(_INPUTEVENTCHAR)

InputEventChar = enum_type_wrapper.EnumTypeWrapper(_INPUTEVENTCHAR)
Unset = 0
US = 1
EU433 = 2
EU868 = 3
CN = 4
JP = 5
ANZ = 6
KR = 7
TW = 8
RU = 9
IN = 10
NZ865 = 11
TH = 12
Client = 0
ClientMute = 1
Router = 2
RouterClient = 3
MAUnset = 0
MA100 = 1
MA190 = 2
MA280 = 3
MA360 = 4
MA450 = 5
MA550 = 6
MA630 = 7
MA700 = 8
MA780 = 9
MA880 = 10
MA960 = 11
MA1000 = 12
MA1080 = 13
MA1160 = 14
MA1240 = 15
MA1320 = 16
GpsFormatDec = 0
GpsFormatDMS = 1
GpsFormatUTM = 2
GpsFormatMGRS = 3
GpsFormatOLC = 4
GpsFormatOSGR = 5
POS_UNDEFINED = 0
POS_ALTITUDE = 1
POS_ALT_MSL = 2
POS_GEO_SEP = 4
POS_DOP = 8
POS_HVDOP = 16
POS_BATTERY = 32
POS_SATINVIEW = 64
POS_SEQ_NOS = 128
POS_TIMESTAMP = 256
KEY_NONE = 0
KEY_UP = 17
KEY_DOWN = 18
KEY_LEFT = 19
KEY_RIGHT = 20
KEY_SELECT = 10
KEY_BACK = 27
KEY_CANCEL = 24


_RADIOCONFIG_USERPREFERENCES_SERIAL_BAUD = _descriptor.EnumDescriptor(
  name='Serial_Baud',
  full_name='RadioConfig.UserPreferences.Serial_Baud',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BAUD_Default', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_2400', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_4800', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_9600', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_19200', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_38400', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_57600', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_115200', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_230400', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_460800', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_576000', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAUD_921600', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3144,
  serialized_end=3353,
)
_sym_db.RegisterEnumDescriptor(_RADIOCONFIG_USERPREFERENCES_SERIAL_BAUD)

_RADIOCONFIG_USERPREFERENCES_SERIAL_MODE = _descriptor.EnumDescriptor(
  name='Serial_Mode',
  full_name='RadioConfig.UserPreferences.Serial_Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_Default', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODE_SIMPLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODE_PROTO', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3355,
  serialized_end=3419,
)
_sym_db.RegisterEnumDescriptor(_RADIOCONFIG_USERPREFERENCES_SERIAL_MODE)

_RADIOCONFIG_USERPREFERENCES_TELEMETRYSENSORTYPE = _descriptor.EnumDescriptor(
  name='TelemetrySensorType',
  full_name='RadioConfig.UserPreferences.TelemetrySensorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DHT11', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DS18B20', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DHT12', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DHT21', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DHT22', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BME280', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BME680', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MCP9808', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHTC3', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3422,
  serialized_end=3558,
)
_sym_db.RegisterEnumDescriptor(_RADIOCONFIG_USERPREFERENCES_TELEMETRYSENSORTYPE)


_RADIOCONFIG_USERPREFERENCES = _descriptor.Descriptor(
  name='UserPreferences',
  full_name='RadioConfig.UserPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position_broadcast_secs', full_name='RadioConfig.UserPreferences.position_broadcast_secs', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_broadcast_smart_disabled', full_name='RadioConfig.UserPreferences.position_broadcast_smart_disabled', index=1,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_owner_interval', full_name='RadioConfig.UserPreferences.send_owner_interval', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_bluetooth_secs', full_name='RadioConfig.UserPreferences.wait_bluetooth_secs', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='screen_on_secs', full_name='RadioConfig.UserPreferences.screen_on_secs', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_timeout_secs', full_name='RadioConfig.UserPreferences.phone_timeout_secs', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_sds_timeout_sec', full_name='RadioConfig.UserPreferences.phone_sds_timeout_sec', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mesh_sds_timeout_secs', full_name='RadioConfig.UserPreferences.mesh_sds_timeout_secs', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sds_secs', full_name='RadioConfig.UserPreferences.sds_secs', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ls_secs', full_name='RadioConfig.UserPreferences.ls_secs', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_wake_secs', full_name='RadioConfig.UserPreferences.min_wake_secs', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wifi_ssid', full_name='RadioConfig.UserPreferences.wifi_ssid', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wifi_password', full_name='RadioConfig.UserPreferences.wifi_password', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wifi_ap_mode', full_name='RadioConfig.UserPreferences.wifi_ap_mode', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='RadioConfig.UserPreferences.region', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge_current', full_name='RadioConfig.UserPreferences.charge_current', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='RadioConfig.UserPreferences.role', index=16,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_low_power', full_name='RadioConfig.UserPreferences.is_low_power', index=17,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed_position', full_name='RadioConfig.UserPreferences.fixed_position', index=18,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_disabled', full_name='RadioConfig.UserPreferences.serial_disabled', index=19,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_share_disabled', full_name='RadioConfig.UserPreferences.location_share_disabled', index=20,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_disabled', full_name='RadioConfig.UserPreferences.gps_disabled', index=21,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_update_interval', full_name='RadioConfig.UserPreferences.gps_update_interval', index=22,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_attempt_time', full_name='RadioConfig.UserPreferences.gps_attempt_time', index=23,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_accept_2d', full_name='RadioConfig.UserPreferences.gps_accept_2d', index=24,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_max_dop', full_name='RadioConfig.UserPreferences.gps_max_dop', index=25,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency_offset', full_name='RadioConfig.UserPreferences.frequency_offset', index=26,
      number=41, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_server', full_name='RadioConfig.UserPreferences.mqtt_server', index=27,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_disabled', full_name='RadioConfig.UserPreferences.mqtt_disabled', index=28,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps_format', full_name='RadioConfig.UserPreferences.gps_format', index=29,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='factory_reset', full_name='RadioConfig.UserPreferences.factory_reset', index=30,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_log_enabled', full_name='RadioConfig.UserPreferences.debug_log_enabled', index=31,
      number=101, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_incoming', full_name='RadioConfig.UserPreferences.ignore_incoming', index=32,
      number=103, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_enabled', full_name='RadioConfig.UserPreferences.serial_module_enabled', index=33,
      number=120, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_echo', full_name='RadioConfig.UserPreferences.serial_module_echo', index=34,
      number=121, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_rxd', full_name='RadioConfig.UserPreferences.serial_module_rxd', index=35,
      number=122, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_txd', full_name='RadioConfig.UserPreferences.serial_module_txd', index=36,
      number=123, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_baud', full_name='RadioConfig.UserPreferences.serial_module_baud', index=37,
      number=176, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_timeout', full_name='RadioConfig.UserPreferences.serial_module_timeout', index=38,
      number=124, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_module_mode', full_name='RadioConfig.UserPreferences.serial_module_mode', index=39,
      number=125, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_enabled', full_name='RadioConfig.UserPreferences.ext_notification_module_enabled', index=40,
      number=126, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_output_ms', full_name='RadioConfig.UserPreferences.ext_notification_module_output_ms', index=41,
      number=127, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_output', full_name='RadioConfig.UserPreferences.ext_notification_module_output', index=42,
      number=128, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_active', full_name='RadioConfig.UserPreferences.ext_notification_module_active', index=43,
      number=129, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_alert_message', full_name='RadioConfig.UserPreferences.ext_notification_module_alert_message', index=44,
      number=130, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_notification_module_alert_bell', full_name='RadioConfig.UserPreferences.ext_notification_module_alert_bell', index=45,
      number=131, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_test_module_enabled', full_name='RadioConfig.UserPreferences.range_test_module_enabled', index=46,
      number=132, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_test_module_sender', full_name='RadioConfig.UserPreferences.range_test_module_sender', index=47,
      number=133, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_test_module_save', full_name='RadioConfig.UserPreferences.range_test_module_save', index=48,
      number=134, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_forward_module_enabled', full_name='RadioConfig.UserPreferences.store_forward_module_enabled', index=49,
      number=148, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_forward_module_heartbeat', full_name='RadioConfig.UserPreferences.store_forward_module_heartbeat', index=50,
      number=149, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_forward_module_records', full_name='RadioConfig.UserPreferences.store_forward_module_records', index=51,
      number=137, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_forward_module_history_return_max', full_name='RadioConfig.UserPreferences.store_forward_module_history_return_max', index=52,
      number=138, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_forward_module_history_return_window', full_name='RadioConfig.UserPreferences.store_forward_module_history_return_window', index=53,
      number=139, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_measurement_enabled', full_name='RadioConfig.UserPreferences.telemetry_module_environment_measurement_enabled', index=54,
      number=140, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_screen_enabled', full_name='RadioConfig.UserPreferences.telemetry_module_environment_screen_enabled', index=55,
      number=141, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_read_error_count_threshold', full_name='RadioConfig.UserPreferences.telemetry_module_environment_read_error_count_threshold', index=56,
      number=142, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_device_update_interval', full_name='RadioConfig.UserPreferences.telemetry_module_device_update_interval', index=57,
      number=143, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_recovery_interval', full_name='RadioConfig.UserPreferences.telemetry_module_environment_recovery_interval', index=58,
      number=144, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_display_fahrenheit', full_name='RadioConfig.UserPreferences.telemetry_module_environment_display_fahrenheit', index=59,
      number=145, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_sensor_type', full_name='RadioConfig.UserPreferences.telemetry_module_environment_sensor_type', index=60,
      number=146, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_sensor_pin', full_name='RadioConfig.UserPreferences.telemetry_module_environment_sensor_pin', index=61,
      number=147, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_flags', full_name='RadioConfig.UserPreferences.position_flags', index=62,
      number=150, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_always_powered', full_name='RadioConfig.UserPreferences.is_always_powered', index=63,
      number=151, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_screen_carousel_secs', full_name='RadioConfig.UserPreferences.auto_screen_carousel_secs', index=64,
      number=152, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_battery_shutdown_after_secs', full_name='RadioConfig.UserPreferences.on_battery_shutdown_after_secs', index=65,
      number=153, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hop_limit', full_name='RadioConfig.UserPreferences.hop_limit', index=66,
      number=154, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_username', full_name='RadioConfig.UserPreferences.mqtt_username', index=67,
      number=155, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_password', full_name='RadioConfig.UserPreferences.mqtt_password', index=68,
      number=156, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_lora_tx_disabled', full_name='RadioConfig.UserPreferences.is_lora_tx_disabled', index=69,
      number=157, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_power_saving', full_name='RadioConfig.UserPreferences.is_power_saving', index=70,
      number=158, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rotary1_enabled', full_name='RadioConfig.UserPreferences.rotary1_enabled', index=71,
      number=160, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_pin_a', full_name='RadioConfig.UserPreferences.inputbroker_pin_a', index=72,
      number=161, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_pin_b', full_name='RadioConfig.UserPreferences.inputbroker_pin_b', index=73,
      number=162, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_pin_press', full_name='RadioConfig.UserPreferences.inputbroker_pin_press', index=74,
      number=163, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_event_cw', full_name='RadioConfig.UserPreferences.inputbroker_event_cw', index=75,
      number=164, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_event_ccw', full_name='RadioConfig.UserPreferences.inputbroker_event_ccw', index=76,
      number=165, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputbroker_event_press', full_name='RadioConfig.UserPreferences.inputbroker_event_press', index=77,
      number=166, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updown1_enabled', full_name='RadioConfig.UserPreferences.updown1_enabled', index=78,
      number=167, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canned_message_module_enabled', full_name='RadioConfig.UserPreferences.canned_message_module_enabled', index=79,
      number=170, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canned_message_module_allow_input_source', full_name='RadioConfig.UserPreferences.canned_message_module_allow_input_source', index=80,
      number=171, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canned_message_module_send_bell', full_name='RadioConfig.UserPreferences.canned_message_module_send_bell', index=81,
      number=173, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_encryption_enabled', full_name='RadioConfig.UserPreferences.mqtt_encryption_enabled', index=82,
      number=174, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adc_multiplier_override', full_name='RadioConfig.UserPreferences.adc_multiplier_override', index=83,
      number=175, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_module_environment_update_interval', full_name='RadioConfig.UserPreferences.telemetry_module_environment_update_interval', index=84,
      number=177, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RADIOCONFIG_USERPREFERENCES_SERIAL_BAUD,
    _RADIOCONFIG_USERPREFERENCES_SERIAL_MODE,
    _RADIOCONFIG_USERPREFERENCES_TELEMETRYSENSORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=3566,
)

_RADIOCONFIG = _descriptor.Descriptor(
  name='RadioConfig',
  full_name='RadioConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='RadioConfig.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RADIOCONFIG_USERPREFERENCES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=3566,
)

_RADIOCONFIG_USERPREFERENCES.fields_by_name['region'].enum_type = _REGIONCODE
_RADIOCONFIG_USERPREFERENCES.fields_by_name['charge_current'].enum_type = _CHARGECURRENT
_RADIOCONFIG_USERPREFERENCES.fields_by_name['role'].enum_type = _ROLE
_RADIOCONFIG_USERPREFERENCES.fields_by_name['gps_format'].enum_type = _GPSCOORDINATEFORMAT
_RADIOCONFIG_USERPREFERENCES.fields_by_name['serial_module_baud'].enum_type = _RADIOCONFIG_USERPREFERENCES_SERIAL_BAUD
_RADIOCONFIG_USERPREFERENCES.fields_by_name['serial_module_mode'].enum_type = _RADIOCONFIG_USERPREFERENCES_SERIAL_MODE
_RADIOCONFIG_USERPREFERENCES.fields_by_name['telemetry_module_environment_sensor_type'].enum_type = _RADIOCONFIG_USERPREFERENCES_TELEMETRYSENSORTYPE
_RADIOCONFIG_USERPREFERENCES.fields_by_name['inputbroker_event_cw'].enum_type = _INPUTEVENTCHAR
_RADIOCONFIG_USERPREFERENCES.fields_by_name['inputbroker_event_ccw'].enum_type = _INPUTEVENTCHAR
_RADIOCONFIG_USERPREFERENCES.fields_by_name['inputbroker_event_press'].enum_type = _INPUTEVENTCHAR
_RADIOCONFIG_USERPREFERENCES.containing_type = _RADIOCONFIG
_RADIOCONFIG_USERPREFERENCES_SERIAL_BAUD.containing_type = _RADIOCONFIG_USERPREFERENCES
_RADIOCONFIG_USERPREFERENCES_SERIAL_MODE.containing_type = _RADIOCONFIG_USERPREFERENCES
_RADIOCONFIG_USERPREFERENCES_TELEMETRYSENSORTYPE.containing_type = _RADIOCONFIG_USERPREFERENCES
_RADIOCONFIG.fields_by_name['preferences'].message_type = _RADIOCONFIG_USERPREFERENCES
DESCRIPTOR.message_types_by_name['RadioConfig'] = _RADIOCONFIG
DESCRIPTOR.enum_types_by_name['RegionCode'] = _REGIONCODE
DESCRIPTOR.enum_types_by_name['Role'] = _ROLE
DESCRIPTOR.enum_types_by_name['ChargeCurrent'] = _CHARGECURRENT
DESCRIPTOR.enum_types_by_name['GpsCoordinateFormat'] = _GPSCOORDINATEFORMAT
DESCRIPTOR.enum_types_by_name['PositionFlags'] = _POSITIONFLAGS
DESCRIPTOR.enum_types_by_name['InputEventChar'] = _INPUTEVENTCHAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadioConfig = _reflection.GeneratedProtocolMessageType('RadioConfig', (_message.Message,), {

  'UserPreferences' : _reflection.GeneratedProtocolMessageType('UserPreferences', (_message.Message,), {
    'DESCRIPTOR' : _RADIOCONFIG_USERPREFERENCES,
    '__module__' : 'radioconfig_pb2'
    # @@protoc_insertion_point(class_scope:RadioConfig.UserPreferences)
    })
  ,
  'DESCRIPTOR' : _RADIOCONFIG,
  '__module__' : 'radioconfig_pb2'
  # @@protoc_insertion_point(class_scope:RadioConfig)
  })
_sym_db.RegisterMessage(RadioConfig)
_sym_db.RegisterMessage(RadioConfig.UserPreferences)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
